/**
 * 这是与购物有关的业务逻辑的服务
 */
export default class OrderService {
    constructor(AjaxService) {
        Object.assign(this, { AjaxService })
        this.name = 'OrderService'
    }
    /**
	 *识别收款短信
	 * @param smsContent 短信内容
	 * @param openid 微信openid
    /**/
    orderReceiptReadSms (data = {}) {
        return this.AjaxService.post({ 
            url:'/order/receipt/read/sms', 
            data, 
            isLoading: true ,
            loadText: '识别中...'
              
        })
    }
    /**
	 *获取收款账号
	/**/
    orderReceiptType (data = {}) {
        return this.AjaxService.get({ 
            url:'/order/receipt/type', 
            data, 
            isLoading: false ,
        })
    }
    /**
	 *获取收款详情的款项类型
	/**/
    orderReceiptDetailType (data = {}) {
        return this.AjaxService.get({ 
            url:'/order/receipt/detail/type', 
            data, 
            isLoading: false ,
        })
    }
    /**
	 *保存收款
	 * @param smsContent 短信内容
	 * @param payType 付款类型
	 * @param receiptType 收款账号
	 * @param receiptAmount 收款金额
	 * @param handlingFee 手续费
	 * @param receiptDate 收款时间
	/**/
    orderReceiptSave(data = {}) {
        return this.AjaxService.post({ 
            url:'/order/receipt/save', 
            data, 
            isLoading: true ,
            loadText: '保存中...' 
        })
    }
    /**
	 *获取收款列表
	 * @param startDate 筛选开始时间
	 * @param endDate 筛选结束时间
	 * @param pageNum 页码
	 * @param pageSize 条数
	 * @param receiptStatus 收款状态：0全部 1待确认、2已确认(待审核)、3审核通过、4审核未通过、5收款撤销【线上支付成功为审核通过】
	 * @param receiptType 款项类型：1订单款，2非订单款，3返佣款 4订单款或者非订单款（因财务阶段无法区分订单非订单）, 5供应商退款
	 * @param smsContent 收款短信
	/**/
    orderReceiptList(data = {}) {
        return this.AjaxService.get({ 
            url:'/order/receipt/list', 
            data, 
            isLoading: false ,
        })
    }
    /**
	 *获取供应商退款收款详情
	 * @param id 款项Id
	/**/
    orderReceiptRefundDetail(data = {}) {
        return this.AjaxService.get({ 
            url:'/order/receipt/refund', 
            data, 
            isLoading: false ,
        })
    }
    /**
	 *返佣收款详情
	 * @param Id 款项Id
	/**/
    orderReceiptRebateDetails(data = {}) {
	    return this.AjaxService.get({ 
	        url:'/order/receipt/rebate', 
	        data, 
	        isLoading: false ,
	    })
    }
    /**
	 *获取收款详情
	 * @param id 款项Id
	/**/
    orderReceiptDetail(data = {}) {
        return this.AjaxService.get({ 
            url:'/order/receipt/detail', 
            data, 
            isLoading: false ,
        })
    }
    /**
	 *获取收款详情分享
	 * @param id 款项Id
	/**/
    orderReceiptShareDetail(data = {}) {
        return this.AjaxService.get({ 
            url:'/order/receipt/detail/share', 
            data, 
            isLoading: false ,
        })
    }
    /**
	 *操作收款信息（作废，设为返佣-普通-供应商退款-非订单款）
	 * @param id 款项Id
	 * @param openid 微信openid
	/**/
    orderReceiptOperate(data = {}) {
        return this.AjaxService.post({ 
            url:'/order/receipt/operate', 
            data, 
            isLoading: true ,
            loadText: '请稍候...' 
        })
    }
    /**
	 *收款详情-订单列表
	 * @param id 收款Id
	 * @param keyword 搜索关键词(客户名称/订单号)
	 * @param orderReceiptStatus 订单收款状态：1待收款(服务商待确认款项的订单)，2部分收款（已确认款项的订单），3已收款（已确认款项的订单）
	 * @param organizeId 组织ID
	 * @param pageNum 页码
	 * @param pageSize 条数
	 * @param type 0商品订单(默认)，1订金订单
	/**/
    orderReceiptOrders(data = {}) {
        return this.AjaxService.get({ 
            url:'/order/receipt/detail/orders', 
            data, 
            isLoading: false
        })
    }
    /**
	 *收款详情-供应商退款-子订单列表
	 * @param id 收款Id
	 * @param confirmedType 0待确认，2已确认
	 * @param shopName 供应商名称
	 * @param pageNum 页码
	 * @param pageSize 条数
	/**/
    orderReceiptRefundOrders(data = {}) {
        return this.AjaxService.get({ 
            url:'/order/receipt/refund/orders', 
            data, 
            isLoading: false
        })
    }
    /**
	 *关联普通款
	 * @param id 收款Id
	 * @param confirmType 确认订单类型：1小额抹平确认，2大额抹平确认，3大额退款余额，4确认关联
	 * @param orderIds 订单Id
	/**/
    orderReceiptConfirm(data = {}) {
        return this.AjaxService.post({ 
            url:'/order/receipt/confirm', 
            data, 
            isLoading: true ,
            loadText: '处理中...' 
        })
    }
    /**
	 *审核普通款项
	 * @param id 收款Id
	 * @param receiptStatus 收款状态：1待确认、2已确认(待审核)、3审核通过、4审核未通过、5收款撤销【线上支付成功为审核通过】
	 * @param reviewReason 不通过说明
	/**/
    orderReceiptAudit(data = {}) {
        return this.AjaxService.post({ 
            url:'/order/receipt/audit', 
            data, 
            isLoading: true ,
            loadText: '处理中...' 
        })
    }
    /**
	 *收款订单详情
	 * @param orderId 订单Id
	/**/
    orderReceiptOrdersInfo(data = {}) {
        return this.AjaxService.get({ 
            url:'/order/receipt/detail/orders/info', 
            data, 
            isLoading: true 
        })
    }
    /**
	 *返佣关联子订单列表
	 * @param id 收款Id
	 * @param confirmedType 0待确认，2已确认子订单
	 * @param keyword 搜索关键词(供应商名称/订单号)
	 * @param pageNum 页码
	 * @param pageSize 条数
	/**/
    orderReceiptRebateOrders(data = {}) {
        return this.AjaxService.get({ 
            url:'/order/receipt/rebate/orders', 
            data, 
            isLoading: false ,
        })
    }
    /**
	 *返佣关联
	 * @param shopOrderId 子订单Id
	/**/
    orderReceiptConfirmRebate(data = {}) {
	    return this.AjaxService.post({ 
	        url:'/order/receipt/confirm/rebate', 
	        data, 
	        isLoading: true ,
	        loadText: '处理中...' 
	    })
    }
    /**
	 *口头返佣关联
	 * @param shopOrderId 子订单Id
	 * @param verbalAmount 口头返佣佣金
	 * @param rebateRemarks 备注
	/**/
    orderReceiptConfirmRebateVerbal(data = {}) {
        return this.AjaxService.post({ 
            url:'/order/receipt/confirm/rebate/verbal', 
            data, 
            isLoading: true ,
            loadText: '处理中...' 
        })
    }
    /**
	 *平台服务费关联
	 * @param Id 收款Id
	 * @param shopOrderId 子订单Id
	/**/
    orderReceiptConfirmPlatform(data = {}) {
	    return this.AjaxService.post({ 
	        url:'/order/receipt/confirm/platform', 
	        data, 
	        isLoading: true ,
	        loadText: '处理中...' 
	    })
    }
    /**
	 *平台服务费欠款关联
	 * @param shopOrderId 子订单Id
	 * @param verbalAmount 子订单平台服务费
	/**/
    orderReceiptConfirmBill(data = {}) {
	    return this.AjaxService.post({ 
	        url:'/order/receipt/confirm/bill', 
	        data, 
	        isLoading: true ,
	        loadText: '处理中...' 
	    })
    }
    /**
	 *平台服务费关联子订单列表
	 * @param id 收款Id
	 * @param keyword 搜索关键词(供应商名称/订单号)
	 * @param pageNum 页码
	 * @param pageSize 条数
	/**/
    orderReceiptPlatformOrders(data = {}) {
	    return this.AjaxService.get({ 
	        url:'/order/receipt/platform/orders', 
	        data, 
	        isLoading: false ,
	    })
    }
	
    /**
	 *关联供应商退款
	 * @param Id 收款Id
	 * @param shopOrderId 子订单Id
	/**/
    orderReceiptConfirmRefund(data = {}) {
	    return this.AjaxService.post({ 
	        url:'/order/receipt/confirm/refund', 
	        data, 
	        isLoading: true ,
	        loadText: '处理中...' 
	    })
    }
    /**
	 *非订单关联查询供应商
	 * @param keyWord 关键词
	 * @param newReceiptType 查询供应商的类别 1上架费供应商  3认证通会员供应商  4认证通企划供应商
	/**/
    orderNoReceiptShopList(data = {}) {
	    return this.AjaxService.get({ 
	        url:'/order/receipt/shop', 
	        data, 
	        isLoading: true ,
	    })
    }
    /**
	 *非订单款关联订单列表
	 * @param keyWord 关键词
	/**/
    orderNoReceiptShoporderList(data = {}) {
	    return this.AjaxService.get({ 
	        url:'/order/receipt/shoporder', 
	        data, 
	        isLoading: false ,
	    })
    }
	
}
